Download and Load a Quebec Election Study
get_qes.RdDownloads a study file from Dataverse, applies labels when available, and attaches a codebook.
Arguments
- srvy
A qesR survey code from
get_qescodes().- file
Optional regular expression for choosing one file in multi-file datasets.
- assign_global
If TRUE, assign the result into the global environment using
srvy.- with_codebook
If TRUE, attach codebook metadata and assign
<srvy>_codebookwhenassign_global = TRUE.- quiet
If TRUE, suppress informational output.